@@ -63,7 +63,7 @@ def init_db():
         print(Child.query.filter(Child.id==0).first())
         db.session.add(Child(unique_id="self",id=0))
         db.session.commit()
-    db_actions={1:_v1,2:_v2,3:_v3,6:_v6,8:_v8,9:_v9,10:_v10,11:_v11,12:_v12,13:_v13,14:_v14}
+    db_actions={1:_v1,2:_v2,3:_v3,6:_v6,8:_v8,9:_v9,10:_v10,11:_v11,12:_v12,13:_v13,14:_v14,16:_v16}
     for ver,db_action in db_actions.items():
         if ver<=db_version:continue
         if start_version==0 and ver==10:continue
@@ -72,8 +72,8 @@ def init_db():
         
         print(f"Updated successfuly db from version {db_version} to {ver}")
         db_version=ver
-        set_hconfig(ConfigEnum.db_version,db_version,commit=False)
         db.session.commit()
+        set_hconfig(ConfigEnum.db_version,db_version,commit=False)
     # 
     if hconfig(ConfigEnum.is_parent) and ParentDomain.query.count()==0:
         external_ip=hiddify.get_ip(4)
@@ -81,6 +81,19 @@ def init_db():
     db.session.commit()
     return BoolConfig.query.all()
 
+def _v16():
+    try:
+        if BoolConfig.query.filter(BoolConfig.key==ConfigEnum.tuic_enable).count()==0:
+            db.session.add(BoolConfig(key=ConfigEnum.tuic_enable,value=False,child_id=0))
+        if BoolConfig.query.filter(BoolConfig.key==ConfigEnum.shadowtls_enable).count()==0:
+            db.session.add(BoolConfig(key=ConfigEnum.shadowtls_enable,value=False,child_id=0))
+        if StrConfig.query.filter(StrConfig.key==ConfigEnum.shadowtls_fakedomain).count()==0:
+            db.session.add(StrConfig(key=ConfigEnum.shadowtls_fakedomain, value="en.wikipedia.org",child_id=0))
+    except Exception as e:
+        print(e)
+
+        
+
 def _v14():
     db.session.add(StrConfig(key=ConfigEnum.utls,value="chrome",child_id=0))
     
