@@ -46,9 +46,10 @@ class UserView(FlaskView):
     @route('/clash/proxies.yml')
     def clash_proxies(self,meta_or_normal="normal"):
         mode=request.args.get("mode")
+        domain=request.args.get("domain",None)
         
         
-        c=get_common_data(g.user_uuid,mode)
+        c=get_common_data(g.user_uuid,mode,filter_domain=domain)
         resp= Response(render_template('clash_proxies.yml',meta_or_normal=meta_or_normal,**c))
         resp.mimetype="text/plain"
         
@@ -93,34 +94,40 @@ def do_base_64(str):
     resp=base64.b64encode(f'{str}'.encode("utf-8"))
     return resp.decode()
     
-def get_common_data(user_uuid,mode):
-    domain=urlparse(request.base_url).hostname
-    if hconfig(ConfigEnum.is_parent):
-        db_domain=ParentDomain.query.filter(ParentDomain.domain==domain).first() or ParentDomain(domain=domain,show_domains=[])
-    else:
-        db_domain=Domain.query.filter(Domain.domain==domain).first() or Domain(domain=domain,mode=DomainType.direct,cdn_ip='',show_domains=[])
-
-    if not db_domain:
-        db_domain=Domain(domain=domain,mode=DomainType.direct,show_domains=[])
-        flash(_("This domain does not exist in the panel!" + domain))
-
-    if mode =='multi':
-        domains=Domain.query.all()
-    elif mode =='new':
-        db_domain=Domain.query.filter(Domain.domain==domain).first()
-        domains=db_domain.show_domains or Domain.query.all()
-    else:
-        
+def get_common_data(user_uuid,mode,no_domain=False,filter_domain=None):
+    
+    if filter_domain:
+        domain=filter_domain
+        db_domain=Domain.query.filter(Domain.domain==domain).first() or Domain(domain=domain,mode=DomainType.direct,cdn_ip='',show_domains=[],child_id=0)
         domains=[db_domain]
-        direct_host= domain
-
-        # if db_domain and db_domain.mode==DomainType.cdn:
-        #     direct_domain_db=Domain.query.filter(Domain.mode==DomainType.direct).first()
-            # if not direct_domain_db:
-            #     direct_host=urllib.request.urlopen('https://v4.ident.me/').read().decode('utf8')
-            #     direct_domain_db=Domain(domain=direct_host,mode=DomainType.direct)
+    else:
+        domain=urlparse(request.base_url).hostname if not no_domain else None
+        if hconfig(ConfigEnum.is_parent):
+            db_domain=ParentDomain.query.filter(ParentDomain.domain==domain).first() or ParentDomain(domain=domain,show_domains=[])
+        else:
+            db_domain=Domain.query.filter(Domain.domain==domain).first() or Domain(domain=domain,mode=DomainType.direct,cdn_ip='',show_domains=[])
+        if not db_domain:
+            db_domain=Domain(domain=domain,mode=DomainType.direct,show_domains=[])
+            print("no domain")
+            flash(_("This domain does not exist in the panel!" + domain))
+        print("HI")
+        if mode =='multi':
+            domains=Domain.query.all()
+        elif mode =='new':
+            db_domain=Domain.query.filter(Domain.domain==domain).first()
+            domains=db_domain.show_domains or Domain.query.all()
+        else:
             
-            # domains.append(direct_domain_db)
+            domains=[db_domain]
+            direct_host= domain
+
+            # if db_domain and db_domain.mode==DomainType.cdn:
+            #     direct_domain_db=Domain.query.filter(Domain.mode==DomainType.direct).first()
+                # if not direct_domain_db:
+                #     direct_host=urllib.request.urlopen('https://v4.ident.me/').read().decode('utf8')
+                #     direct_domain_db=Domain(domain=direct_host,mode=DomainType.direct)
+                
+                # domains.append(direct_domain_db)
         
         
 
@@ -138,7 +145,12 @@ def get_common_data(user_uuid,mode):
         UserMode.monthly:30
 
     }
+    from hiddifypanel.panel.telegrambot import bot
     g.locale= hconfig(ConfigEnum.lang)
+    reset_days=package_mode_dic.get(user.mode,10000)-(datetime.date.today()-user.last_reset_time).days
+    expire_days=(user.expiry_time-datetime.date.today()).days
+    if reset_days<=expire_days:
+        reset_days=1000
     return {
         # 'direct_host':direct_host,
         'user':user,
@@ -148,14 +160,15 @@ def get_common_data(user_uuid,mode):
         'usage_limit_b':int(user.usage_limit_GB*1024*1024*1024),
         'usage_current_b':int(user.current_usage_GB*1024*1024*1024),
         'expire_s':int((user.expiry_time-datetime.date(1970, 1, 1)).total_seconds()),
-        'expire_days':(user.expiry_time-datetime.date.today()).days,
+        'expire_days':expire_days,
         'expire_rel':hiddify.format_timedelta(user.expiry_time-datetime.date.today()),
-        'reset_day':package_mode_dic.get(user.mode,1000)-(datetime.date.today()-user.last_reset_time).days,
+        'reset_day':reset_days,
         'hconfigs':get_hconfigs(),
         'hdomains':get_hdomains(),
         'ConfigEnum':ConfigEnum,
         'link_maker':link_maker,
-        'domains':domains
+        'domains':domains,
+        "bot":bot
 
     }
     
\ No newline at end of file
